@@ -2,6 +2,8 @@
 ### attach package `modeltools'
 
 .onLoad <- function(lib, pkg) {
+    if (!require("modeltools"))
+        stop("cannot load ", sQuote("modeltools"))
     if (!require("party"))
         stop("cannot load ", sQuote("party"))
     return(TRUE)
